function [logpostr]=logpostgam(type,W,Xr,p,r,alpha0,h0,beta0r,Hg,lambda,v0,v2,w,d)

%logpostgam: log posterior probability of model r
%
%***********************************************************************
%INPUTS:
% type:  1=log-normal,2=log-t
% W:     "complete pseudo" data.
% X:     covariate data. 
% p:     total number of covariates 
% r:     model vector.
%
%OUTPUT:
% logpostr: log posterior probability of model r
%
%NOTES:
% Called by metro_surv
% Functions called: none
%
%REFERENCE:
%  
%     
%Copyright (c) 2006 Naijun Sha and Marina Vannucci.
%**********************************************************************

n=length(W);
pr=length(r);
Hgr=Hg(r,r);
      
switch type   %---distribution type
   case 1        %---log-normal data
       Pr=eye(n)+h0*ones(n,n)+Xr*Hgr*Xr';
   case 2        %---log t-student
       L=diag(lambda);
       Pr=d^2*L+h0*ones(n,n)+Xr*Hgr*Xr';
   end
R=chol(Pr);
Rinv=inv(R);
PrINV=Rinv*Rinv';%PrINV=inv(Pr);
switch length(w)
   case 1
       %--Bernoulli prior 
       logpostr=pr*log(w)+(p-pr)*log(1-w)-...
       1/2*log(det(Pr))+v0/2*log(v2)-...
       (n+v0)/2*log(v2+(W-alpha0*ones(n,1)-Xr*beta0r)'*PrINV*(W-alpha0*ones(n,1)-Xr*beta0r));
    case 2
       %--Beta-Bernoulli prior 
       alpha=w(2)*w(1);	% (mean=pw(1), w(2)=alpha+beta) 
	   betapar=w(2)*(1-w(1));
       logpostr=gammaln(alpha+pr)+gammaln(p+betapar-pr)-gammaln(alpha+betapar+p)...
       -1/2*log(det(Pr))+v0/2*log(v2)-...
       (n+v0)/2*log(v2+(W-alpha0*ones(n,1)-Xr*beta0r)'*PrINV*(W-alpha0*ones(n,1)-Xr*beta0r)); 
   end
