function T=multrunct(T,mu,d,P,v,dcen,cenval)

%multrunct: 
%    generates from a multivariate t 
%    truncated based on censored data 
% 
%----INPUTS-----
%mu: t-distribution mean
%P,v: column covariance matrix and row variance
%d: degrees of freedom for multivariate t
%dcen: censoring indicator vector (1==censored)
%cenval: censored values vector

%----OUTPUT-----
%T: truncated t-vector
%
%Copyright (c) 2006 Naijun Sha.
%**********************************************************************
  
n=length(T);dnew=d+n-1;
censorindx=find(~dcen);censorlen=length(censorindx);
for i=1:censorlen
    j=censorindx(i);
    P11=P(j,j);P12=P(j,:);P12(:,j)=[];P21=P12';
    P22=P;P22(j,:)=[];P22(:,j)=[];%P22inv=inv(P22);
    R=chol(P22);Rinv=inv(R);P22inv=Rinv*Rinv';
    a=P11-P12*P22inv*P21;T2=T-mu;T2(j)=[];
    b=v+T2'*P22inv*T2;c=sqrt(a*b/dnew);
    mu1=mu(j);mustar1=P12*P22inv*T2;
    cj=cenval(j);cut=(cj-mu1-mustar1)/c;
    p=tcdf(cut,dnew);
    u=rand(1);
    %---sampling right censored value---
    %if .4991 <= (u*(1-p)+p) <= .5009
    %   Newton procedure does not converge for most df
    while (.4991 <= (u*(1-p)+p)) & ((u*(1-p)+p) <= .5009)
    u=rand(1);
    end
    t1=tinv(u*(1-p)+p,dnew);
    T(j)=mu1+mustar1+c*t1;
end
   
