function [pvalue stat flag power]= censIndLR(xIndex, timeIndex, csIndex, data, censored, threshold)
% Conditional independence test based on the Log Likelihood ratio test

%initialization: these values will be returned whether the test cannot be
%carried out
pvalue = 1;
stat = 0;
flag = 0;
power = 0;

%retrieving the data
x = data(:, xIndex);
time = data(:, timeIndex);
cs = data(:,csIndex);

if isempty(x) || isempty(time)
    return;
end

%if the censored indicator is empty, a dummy variable is created
numCases = size(x,1);
if isempty(censored)
    censored = zeros(numCases,1);
end

%if the conditioning set (cs) is empty, let's take it easy.
if isempty(cs)

    %perform the test. If the coxphfit function launches a warning, the
    %function returns "flag=0", that means "the test cannot be performed"
    lastwarn('');

    [b, log, H, stats] = coxphfit(x, time, 'censoring', censored);
	
    msg = lastwarn;
    if ~strcmp(msg,'')
        disp(msg);
        return
    end
    
    %calculate the p value and stat. Note that we "simulate" that the p
    %value comes from a chi squared distribution, in order to make
    %meaningful comparisons in the MMPC
    pvalue = stats.p(1);
    stat = chi2inv(1-pvalue,1);
    
    %calculate the power
    if pvalue >= threshold
        power = powerCalculation(x, cs, censored, b, threshold);
    else
        power = 1;
    end
    
    flag = 1;
    
else

    %perform the test. If the coxphfit function launches a warning, the
    %function returns "flag=0", that means "the test cannot be performed"
    lastwarn('');

    [b, log] = coxphfit(cs, time, 'censoring', censored);
    log1 = -log;

    msg = lastwarn;
    if ~strcmp(msg,'')
        disp(msg);
        return
    end

    [b,log] = coxphfit([x cs],time,'censoring',censored);
    log2 = -log;

    msg = lastwarn;
    if ~strcmp(msg,'')
        disp(msg);
        return
    end
    
    %calculate the p value
    stat = 2*(log1 - log2);
    dF = size(x,2);
    pvalue = 1 - chi2cdf(stat,dF);
    
    %calculate the power
    if pvalue >= threshold
        power = powerCalculation(x, cs, censored, b(1), threshold);
    else
        power = 1;
    end
    
    flag = 1;
end