function beta = powerCalculation(x, cs, censored, b, alpha)
%
% this function calculate the  power for the conditional independence tests 
% Ind(x, t | covs)
% For the details, see:
%
% Hsieh, F.Y. and Lavori, P.W. 2000. "Sample size calculation for the cox 
% proportional hazards regression model with nonbinary covariates",
% Controlled Clinical Trials, Volume 21, pages 552-560.
%
% Input:
% x: the variable subject to the test
% cs: the conditioning set
% censored: censoring vectr; censored(i) = 1 if the ith subject is censored
% time: survival time
% alpha: the significance threshold
%
% Output:
% beta: 1-probability of Type II error.
%

%values required by the formula
x_var = var(x);
z_alpha = norminv(alpha);
nEvent = sum(censored == 0);

%denominator of the original formula
denominator = x_var * (b^2);

%Variance Inflation Factor (VIF), necessary if the conditioning set is
%present
R2 =0;
if ~isempty(cs)
    [br,bint,r,rint,stats] = regress(x, [cs ones(size(x))]);
    R2 = stats(1);
end

%power: beta is the probability of detecting the presence
z_beta = sqrt((1-R2)*denominator*nEvent) - abs(z_alpha);
beta = normcdf(z_beta);