function [betaIndex statistics] = bayesScoreSelection(data,time,censored,parameter)

%updating the path
path(path, 'FeatureSelection/BayesScoreFiles');
path(path, 'BayesScoreFiles');

%hard coded parameter
parameter.termination = 0.9;
parameter.numVars = 100;
parameter.threshold = 1;
lambdaValue = 0.001;

%parameters (only sigma comes as input)
sigma = parameter.sigma;
termination = parameter.termination;
numVars = parameter.numVars;

%pre selection
[initialBeta pValues]= univariateSelection(data,time,censored,parameter);
[dummy idx] = sort(pValues(1,initialBeta));
initialBeta = initialBeta(idx);
if size(initialBeta,2) < numVars
    numVars = size(initialBeta,2);
end
initialBeta = initialBeta(1:numVars);
numOriginalVars = size(data,2); %the original size of dataset

%b estimation
[b logl H stats] = coxphfit3(data(:,initialBeta), time, 'censoring', censored, 'lambda', lambdaValue);

%covariance matrices
covb = stats.covb;
X = cov(data(:,initialBeta));
clear logl H stats

%alpha calculation
%numVars = length(initialBeta);
inv_c = inv(covb);
D = sigma*eye(numVars);
inv_d = inv(D);
S = inv(inv_c + inv_d);
alpha = S * (inv_c * b);

%fixed error calculation
% mu = mean(data(:,initialBeta));
% fixedError = 0;
% for i = 1:numVars
%     for j = 1:numVars
%         
%         fixedError = fixedError + S(i,j)*(mu(i)*mu(j) + X(i,j));
%         
%     end
% end
        
%null model error
maxError = calculateScore(alpha, X, zeros(1,numVars));

%termination calculation: when we explain more than the termination% (i.e.
%90%) of the variable error, then stop
terminationThreshold = (1 - termination)* maxError;
%disp(['Termination threshold: ' num2str(terminationThreshold)]);

%initializing search algorithm
selectedVars = zeros(1,numVars);
% the "statistics matrix was originally conceived in order to contain two
% rows:
% statistics(1,:) = p values measuring the strenght of the relationship
% between the time and each variable
% statistics(2,:) = statistic (e.g. t statisti, chi squared statistic)
% related to the p values
% So, variables can be ordered following statistics(1,:) breaking the ties
% with statistics(2,:).
% Unfortunately, this method des not give p values; so we use:
% statistics(1,i) = percentage of the log risk explained after the
% inclusion of variable i;
% statistics(2,i) = inverse of the inclusion order (i.e.: the first
% variable to be included has statistics(2,i) = numVars, the second
% variable to be included statistics(2,i) = numVars -1 etc.).
statistics = zeros(2,numOriginalVars);  

%running the algorithm
exitPoint = false;
insertCount = 1;

while ~exitPoint
    
    newScore = 10000000000; %a very big number!
    newScores = searchNextVar(alpha, X, selectedVars, newScore);
    
    stats_to_be_updated = initialBeta(~selectedVars);
    statistics(1,stats_to_be_updated) = (maxError - newScores(~selectedVars))./maxError;
    newVar = find(newScores == min(newScores));
    disp(['New var: ' num2str(newVar)]);
    if (length(newVar) > 1) %in case there are more than one minimum
        newVar = newVar(1);
    end
    newScore = min(newScores);
    selectedVars(newVar) = 1; %#ok<FNDSB>
    statistics(2,initialBeta(newVar)) = insertCount;
    insertCount = insertCount + 1;
    disp(['New score: ' num2str(newScore)]);
    
    %exit criterion
    if newScore < terminationThreshold || sum(selectedVars) == length(selectedVars)
        
        exitPoint = true;
        
    end
    
end
    
%from pre-selected vars to complete dataset
betaIndex = initialBeta(logical(selectedVars));
%adding the fixed error part
%statistics(1,:) = statistics(1,:) + fixedError;
%transforming the statistics(2,:) in order to have: the higher, the more relevant
notBI = setdiff(1:numOriginalVars, betaIndex);
lengthBI = length(betaIndex);
statistics(2, notBI) = lengthBI + 1;
statistics(2,:) = lengthBI - statistics(2,:) + 1;
% setting statistics(1 notBI) to 1 (no relevance)
statistics(1,notBI) = 1;

function newScores = searchNextVar(alpha, X, previousVars, previousScore)

varsToBeSelected = find(previousVars == 0);
newScores = ones(1, length(previousVars))*previousScore + 1;

for i = varsToBeSelected
    vars = previousVars;
    vars(i) = 1;
    newScores(i)  = calculateScore(alpha, X, vars);
end

function score  = calculateScore(alpha, X, vars)

alphaJ = alpha(~vars);

I = logical(vars);
J = ~logical(vars);

varxII = X(I, I);
varxIJ = X(I, J);
varxJI = X(J, I);
varxJJ = X(J, J);

VJJ = varxJJ - varxJI*inv(varxII)*varxIJ;

score = alphaJ' * VJJ * alphaJ;