
#let's get the command args
magicNumber = 1;
eval(parse(text=commandArgs(trailingOnly=TRUE)[[magicNumber]]));

#library
library(survival);
library(Design);

#function for fitting and testing the AFT model
aft = function(dataset, psmdistr){
	
	#getting basic information
	ncols = ncol(dataset);
	nrows = nrow(dataset);
	
	#separing the data
	trData = dataset[dataset[[ncols]]==1, 1:(ncols-1)];
	teData = dataset[dataset[[ncols]]==0, 1:(ncols-1)];
	trEvent = trData[ , ncols-1]
	teEvent = teData[ , ncols-1];
	trTime = trData[ , ncols - 2];
	teTime = teData[ , ncols - 2];
	trData = data.frame(trData[ , -((ncols-1):(ncols-2))]);
	teData = data.frame(teData[ , -((ncols-1):(ncols-2))]);

	#variables names
	names(trData) = paste('v',1:ncol(trData), sep='')
	names(teData) = paste('v',1:ncol(teData), sep='')	
	
	#let's ensure that calculation can be done
	if (sum(trTime == 0) > 0){
		trTime = trTime + 0.0001;
	}

  #let's fit the model and obtain the predictions
	xnam = names(trData);
	fmla <- as.formula(paste("Surv(trTime, trEvent) ~", paste(xnam, collapse= "+")))
	model = psm(fmla, data = trData,  dist = psmdistr);
	predictions = predict(model, newdata=teData, type = "lp");	
	
	#values to return
	timeOfInterest = sort(trTime[trEvent == 1]);
	ret = list(model, predictions, timeOfInterest);
  names(ret) = c('model', 'predictions', 'timeOfInterest');
  ret

}

#loading the data
dataset = read.table(file = 'Regression/AFT/dataset.csv', sep = ',', row.names = NULL, stringsAsFactors = FALSE);
dataset = data.frame(dataset);

#getting the output
ret = aft(dataset,psmdistr);
predictions = ret$predictions;
model = ret$model;
timeOfInterest = ret$timeOfInterest;

#let's build S!
S_function = Survival(model);
S = matrix(-1, length(predictions), length(timeOfInterest));
for (i in 1:length(predictions)){
	
  S[i, ] = S_function(times = timeOfInterest, lp = predictions[i]);

}

#save the predictions and S
write.table(predictions, file = 'Regression/AFT/aft_predictions.csv', sep = ',', row.names = FALSE, col.names = FALSE, na = '0');
write.table(S, file = 'Regression/AFT/aft_S.csv', sep = ',', row.names = FALSE, col.names = FALSE, na = '0');

