
#let's get the command args
magicNumber = 1;
print(commandArgs(trailingOnly=TRUE)[[magicNumber]])
eval(parse(text=commandArgs(trailingOnly=TRUE)[[magicNumber]]));

#library
library(survival);
library(randomSurvivalForest);

#function for fitting and testing the RSF model
rsf_function = function(dataset, num_trees){
	
	#getting basic information
	ncols = ncol(dataset);
	nrows = nrow(dataset);
	
	#separing the data
	trData = dataset[dataset[[ncols]]==1, 1:(ncols-1)];
	teData = dataset[dataset[[ncols]]==0, 1:(ncols-1)];
	trEvent = trData[ , ncols-1]
	teEvent = teData[ , ncols-1];
	trTime = trData[ , ncols - 2];
	teTime = teData[ , ncols - 2];
	trData = data.frame(trData[ , -((ncols-1):(ncols-2))]);
	teData = data.frame(teData[ , -((ncols-1):(ncols-2))]);

	#variables names
	names(trData) = paste('v',1:ncol(trData), sep='')
	names(teData) = paste('v',1:ncol(teData), sep='')	
	
	#let's ensure that calculation can be done
	if (sum(trTime == 0) > 0){
		trTime = trTime + 0.0001;
	}

  #let's fit the model and obtain the predictions
	#xnam = names(trData);
	#fmla <- as.formula(paste("Survrsf(trTime, trEvent) ~", paste(xnam, collapse= "+")))
	trDataset = data.frame(trData, trTime, trEvent);
	model = rsf(Survrsf(trTime, trEvent) ~., data = trDataset,  forest = TRUE,  ntree=500, big.data = TRUE, splitrule = 'logrank', nsplit = nsplit);
	predictions = predict(model, test=teData);
	
	#values to return
	timeOfInterest = predictions$timeInterest;
	ret = list(model, predictions, timeOfInterest);
  names(ret) = c('model', 'predictions', 'timeOfInterest');
  ret

}

#loading the data
dataset = read.table(file = 'Regression/RSF/dataset.csv', sep = ',', row.names = NULL, stringsAsFactors = FALSE);
dataset = data.frame(dataset);

#getting the output
ret = rsf_function(dataset, num_trees);
predictions = ret$predictions;
model = ret$model;
timeOfInterest = ret$timeOfInterest;

#let's build S and the predictions
H = predictions$ensemble;
S = exp(-H);
diffs = c(timeOfInterest[1], timeOfInterest[2:length(timeOfInterest)] - timeOfInterest[1:(length(timeOfInterest)-1)]);
predictions = S %*% diffs;

#save the predictions and S
write.table(predictions, file = 'Regression/RSF/rsf_predictions.csv', sep = ',', row.names = FALSE, col.names = FALSE);
write.table(S, file = 'Regression/RSF/rsf_S.csv', sep = ',', row.names = FALSE, col.names = FALSE);
write.table(timeOfInterest, file = 'Regression/RSF/rsf_timeOfInterest.csv', sep = ',', row.names = FALSE, col.names = FALSE);

