function [model prediction]= SVCR(trData,trTime,trCensored,teData,teTime,teCensored,parameter)

path('Regression/SVCR',path);
%path('SVCR',path);

%getting the option
option = parameter.string;

%correction... convergence problem with only one var...
num_vars = size(trData,2);
if num_vars == 1 && ~isempty(strfind(option, '-t 0'))

    disp('SVCR correction needed');
    option = [option ' -# 10'];
    disp(option);    
    
end    

%setting up the upper and lower bounds of the time to event
maxTime = 10*max([trTime; teTime]);
trTime_low = trTime;
trTime_up = trTime;
trTime_up(trCensored==1) = maxTime;

%let's normalize the data!
maxima = max(trData);
minima = min(trData);
[trRows trCols] = size(trData);
for i = 1:trCols
    trData(:,i) = (trData(:,i) - minima(i))/(maxima(i) - minima(i));
    teData(:,i) = (teData(:,i) - minima(i))/(maxima(i) - minima(i));
end

%let's write the data on a file
fid = fopen('Regression/SVCR/svcrTrData.dat','w');
for i = 1:size(trData,1)
    line = '';
    line = [line num2str(trTime_low(i))];
    line = [line ' ' num2str(trTime_up(i))];
    for j = 1:size(trData,2)
        line = [line ' ' num2str(j) ':' num2str(trData(i,j))];
    end
    fprintf(fid, '%s\n', line);
end
fclose(fid);


[result logTrace] = system(['.\Regression\SVCR\svm_learn.exe ' option ' .\Regression\SVCR\svcrTrData.dat .\Regression\SVCR\svcr_model']);

if result ~= 0
    save -v6 svm_learn.log logTrace -ASCII;
end

%let's write the test data on a file
fid = fopen('Regression/SVCR/svcrTeData.dat','w');
for i = 1:size(teData,1)
    line = '';
    line = [line num2str(teTime(i))];
    for j = 1:size(teData,2)
        line = [line ' ' num2str(j) ':' num2str(teData(i,j))];
    end
    fprintf(fid, '%s\n', line);
end
fclose(fid);

[result logTrace] = system('.\Regression\SVCR\svm_classify.exe .\Regression\SVCR\svcrTeData.dat .\Regression\SVCR\svcr_model .\Regression\SVCR\svcr_predictions.dat');

if result ~= 0
    save -v6 svm_classify.log logTrace -ASCII;
end

%prediction
prediction = load('Regression/SVCR/svcr_predictions.dat', '-ASCII');

%creating the model
model.type = 'SVCR';
model.timeOfInterest = sort(trTime(trCensored == 0));
model.S = zeros(length(teTime), length(model.timeOfInterest));
for i = 1:size(model.S,1)
   
    model.S(i, model.timeOfInterest < prediction(i)) = 1;
    
end
