function REs_parameters = createRegressionParameters(REs, comboList)

	%return value
	num_REs = length(REs);
	REs_parameters = cell(1, num_REs);

	%let's find them
	for i = 1:num_REs
		
		REs_parameters{i} = find_options(REs{i});

	end

end

function RE_options = find_options(RE)

	%if not found, let's have a fake options
	isfound = false;	

	%magic number fo the ridge; it is the mean of #sample of the datasets
	avesize = 150;

	%Cox
	if strcmp(RE,'coxRegression')
		RE_options = 0;
		isfound = true;
	end
	%Ridge
	if strcmp(RE, 'ridgeRegression')
		g1=13;   
		g00=6;
		g0=0:g1;
		grid1=avesize*2.^(g0-g00);
		for i = 1:length(grid1)
			%here the deal!
			RE_options(i).lambda = grid1(i);
		end
		isfound = true;
	end
	%SVCR
	if strcmp(RE, 'SVCR')
		RE_options(1).string = '-z t -t 0 -c 1 -w 1';
		RE_options(2).string = '-z t -t 0 -c 10 -w 1';
		RE_options(3).string = '-z t -t 0 -c 100 -w 1';
		RE_options(4).string = '-z t -t 1 -d 2 -c 1 -w 1';
		RE_options(5).string = '-z t -t 1 -d 2 -c 10 -w 1';
		RE_options(6).string = '-z t -t 1 -g 2 -c 100 -w 1';
		RE_options(7).string = '-z t -t 2 -g 1 -c 1 -w 1';
		RE_options(8).string = '-z t -t 2 -g 1 -c 10 -w 1';
		RE_options(9).string = '-z t -t 2 -g 1 -c 100 -w 1';
		isfound = true;
	end
	%STree
	if strcmp(RE,'RSF')
		RE_options(1).nsplit = 1;
		RE_options(2).nsplit = 5;	
		RE_options(3).nsplit = 10;
		isfound = true;
	end
	%AFT
    if strcmp(RE,'AFT')
		RE_options(1).dist = 'extreme';
		RE_options(2).dist = 'logistic';
		RE_options(3).dist = 'gaussian';
		RE_options(4).dist = 'weibull';
		RE_options(5).dist = 'exponential';
		RE_options(6).dist = 'lognormal';
		RE_options(7).dist = 'loglogistic';
		isfound = true;
    end
    %Combo
    if strcmp(RE,'combo')
        RE_options(1).null = 0;
        RE_options(1).type = 'coxRegression';        
		RE_options(2).dist = 'extreme';
        RE_options(2).type = 'AFT';        
		RE_options(3).dist = 'logistic';
        RE_options(3).type = 'AFT';        
		RE_options(4).dist = 'gaussian';
        RE_options(4).type = 'AFT';
		RE_options(5).dist = 'weibull';
        RE_options(5).type = 'AFT';
		RE_options(6).dist = 'exponential';
        RE_options(6).type = 'AFT';
		RE_options(7).dist = 'lognormal';
        RE_options(7).type = 'AFT';
		RE_options(8).dist = 'loglogistic';
        RE_options(8).type = 'AFT';
        RE_options(9).lambda = 2.3438;
        RE_options(9).type = 'ridgeRegression';
        RE_options(10).lambda = 4.6875;
        RE_options(10).type = 'ridgeRegression';
        RE_options(11).lambda = 9.3750;
        RE_options(11).type = 'ridgeRegression';
        RE_options(12).lambda = 18.7500;
        RE_options(12).type = 'ridgeRegression';
        RE_options(13).lambda = 37.5000;
        RE_options(13).type = 'ridgeRegression';
        RE_options(14).lambda = 75;
        RE_options(14).type = 'ridgeRegression';
        RE_options(15).lambda = 150;
        RE_options(15).type = 'ridgeRegression';
        RE_options(16).lambda = 300;
        RE_options(16).type = 'ridgeRegression';
        RE_options(17).lambda = 600;
        RE_options(17).type = 'ridgeRegression';
        RE_options(18).lambda = 1200;
        RE_options(18).type = 'ridgeRegression';
        RE_options(19).lambda = 2400;
        RE_options(19).type = 'ridgeRegression';
        RE_options(20).lambda = 4800;
        RE_options(20).type = 'ridgeRegression';
        RE_options(21).lambda = 9600;
        RE_options(21).type = 'ridgeRegression';
        RE_options(22).lambda = 19200;
        RE_options(22).type = 'ridgeRegression';
		RE_options(23).nsplit = 1;
        RE_options(23).type = 'RSF';
		RE_options(24).nsplit = 5;
        RE_options(24).type = 'RSF';
		RE_options(25).nsplit = 10;
        RE_options(25).type = 'RSF';
		RE_options(26).string = '-z t -t 0 -c 1 -w 1';
        RE_options(26).type = 'SVCR';
		RE_options(27).string = '-z t -t 0 -c 10 -w 1';
        RE_options(27).type = 'SVCR';
		RE_options(28).string = '-z t -t 0 -c 100 -w 1';
        RE_options(28).type = 'SVCR';
		RE_options(29).string = '-z t -t 1 -d 2 -c 1 -w 1';
        RE_options(29).type = 'SVCR';
		RE_options(30).string = '-z t -t 1 -d 2 -c 10 -w 1';
        RE_options(30).type = 'SVCR';
		RE_options(31).string = '-z t -t 1 -g 2 -c 100 -w 1';
        RE_options(31).type = 'SVCR';
		RE_options(32).string = '-z t -t 2 -g 1 -c 1 -w 1';
        RE_options(32).type = 'SVCR';
		RE_options(33).string = '-z t -t 2 -g 1 -c 10 -w 1';
        RE_options(33).type = 'SVCR';
		RE_options(34).string = '-z t -t 2 -g 1 -c 100 -w 1';
        RE_options(34).type = 'SVCR';
        isfound = true;
    end
    %Combo no selection
    if strcmp(RE,'comboNo')
        RE_options(1).lambda = 2.3438;
        RE_options(1).type = 'ridgeRegression';
        RE_options(2).lambda = 4.6875;
        RE_options(2).type = 'ridgeRegression';
        RE_options(3).lambda = 9.3750;
        RE_options(3).type = 'ridgeRegression';
        RE_options(4).lambda = 18.7500;
        RE_options(4).type = 'ridgeRegression';
        RE_options(5).lambda = 37.5000;
        RE_options(5).type = 'ridgeRegression';
        RE_options(6).lambda = 75;
        RE_options(6).type = 'ridgeRegression';
        RE_options(7).lambda = 150;
        RE_options(7).type = 'ridgeRegression';
        RE_options(8).lambda = 300;
        RE_options(8).type = 'ridgeRegression';
        RE_options(9).lambda = 600;
        RE_options(9).type = 'ridgeRegression';
        RE_options(10).lambda = 1200;
        RE_options(10).type = 'ridgeRegression';
        RE_options(11).lambda = 2400;
        RE_options(11).type = 'ridgeRegression';
        RE_options(12).lambda = 4800;
        RE_options(12).type = 'ridgeRegression';
        RE_options(13).lambda = 9600;
        RE_options(13).type = 'ridgeRegression';
        RE_options(14).lambda = 19200;
        RE_options(14).type = 'ridgeRegression';
		RE_options(15).nsplit = 1;
        RE_options(15).type = 'RSF';
		RE_options(16).nsplit = 5;
        RE_options(16).type = 'RSF';
		RE_options(17).nsplit = 10;
        RE_options(17).type = 'RSF';
        isfound = true;
    end
    %Combo univariate selection
    if strcmp(RE,'comboUni')
        RE_options(1).lambda = 2.3438;
        RE_options(1).type = 'ridgeRegression';
        RE_options(2).lambda = 4.6875;
        RE_options(2).type = 'ridgeRegression';
        RE_options(3).lambda = 9.3750;
        RE_options(3).type = 'ridgeRegression';
        RE_options(4).lambda = 18.7500;
        RE_options(4).type = 'ridgeRegression';
        RE_options(5).lambda = 37.5000;
        RE_options(5).type = 'ridgeRegression';
        RE_options(6).lambda = 75;
        RE_options(6).type = 'ridgeRegression';
        RE_options(7).lambda = 150;
        RE_options(7).type = 'ridgeRegression';
        RE_options(8).lambda = 300;
        RE_options(8).type = 'ridgeRegression';
        RE_options(9).lambda = 600;
        RE_options(9).type = 'ridgeRegression';
        RE_options(10).lambda = 1200;
        RE_options(10).type = 'ridgeRegression';
        RE_options(11).lambda = 2400;
        RE_options(11).type = 'ridgeRegression';
        RE_options(12).lambda = 4800;
        RE_options(12).type = 'ridgeRegression';
        RE_options(13).lambda = 9600;
        RE_options(13).type = 'ridgeRegression';
        RE_options(14).lambda = 19200;
        RE_options(14).type = 'ridgeRegression';
		RE_options(15).nsplit = 1;
        RE_options(15).type = 'RSF';
		RE_options(16).nsplit = 5;
        RE_options(16).type = 'RSF';
		RE_options(17).nsplit = 10;
        RE_options(17).type = 'RSF';
		RE_options(18).string = '-z t -t 0 -c 1 -w 1';
        RE_options(18).type = 'SVCR';
		RE_options(19).string = '-z t -t 0 -c 10 -w 1';
        RE_options(19).type = 'SVCR';
		RE_options(20).string = '-z t -t 0 -c 100 -w 1';
        RE_options(20).type = 'SVCR';
		RE_options(21).string = '-z t -t 1 -d 2 -c 1 -w 1';
        RE_options(21).type = 'SVCR';
		RE_options(22).string = '-z t -t 1 -d 2 -c 10 -w 1';
        RE_options(22).type = 'SVCR';
		RE_options(23).string = '-z t -t 1 -g 2 -c 100 -w 1';
        RE_options(23).type = 'SVCR';
		RE_options(24).string = '-z t -t 2 -g 1 -c 1 -w 1';
        RE_options(24).type = 'SVCR';
		RE_options(25).string = '-z t -t 2 -g 1 -c 10 -w 1';
        RE_options(25).type = 'SVCR';
		RE_options(26).string = '-z t -t 2 -g 1 -c 100 -w 1';
        RE_options(26).type = 'SVCR';
        isfound = true;
    end
	%otherwise
	if ~isfound
		RE_options = 0;
	end

end
