function [] = evaluationNestedCV(datasets, FSs, REs, ext_metric, int_metric, maximize)

%this function evaluates the predictions and the models provided by the
%regression algorithms. Several evaluation metrics can be used for the
%external folds. For the internal folds only one metric can be used, and it
%is necessary ti specify if the performance values must be maximized (e.g.
%c index) or minimized (e.g. b index).


%hard coded stuff
if isempty(findstr('metrics/', path))
    path(path, 'metrics/');
end
datasetfold = 'dataset/';
outputFolder = 'synthesis/';
regressionResultsFold = 'regressionResults/';

num_ext_metric = length(ext_metric);

for w = 1:length(datasets)

    % dataset: the file must contain the variables: data, time, censored,
    % ext_indices and int_indices
    dataset = datasets{w};
    datasetFile = [datasetfold dataset];
    load(datasetFile);

    %finding the number of external and internal CV
    ext_numFold = max(ext_indices);
    int_numFold = max(int_indices{1,1}); %#ok<USENS>

    for t = 1:length(REs)

        %regression algorithms
        RE = REs{t};

        for z = 1:length(FSs)

            %feaure selection algorithms
            FS = FSs{z};            
            
            %output file
            outputFile = [outputFolder dataset '_' FS '_' RE '_synthesis'];
            
            %loading the results file
            try
                disp(['Evaluation; Processing file: ' dataset '_' FS '_' RE]);
                load([regressionResultsFold dataset '_' FS '_' RE]);
            catch %#ok<CTCH>
                disp(['File: ' dataset '_' FS '_' RE ' not available']);
                ext_evaluations = nan*ones(ext_numFold, num_ext_metric); %#ok<NASGU>
                continue;
            end
            num_FS_parameters = length(FS_options);
            num_RE_parameters = length(RE_options);

            % variables to be set
            int_evaluations = zeros(ext_numFold, int_numFold, num_FS_parameters, num_RE_parameters);
            mean_int_evaluation = zeros(ext_numFold, num_FS_parameters, num_RE_parameters);
            best_FS_parameter = zeros(ext_numFold,1);
            best_RE_parameter = zeros(ext_numFold,1);
            ext_evaluations = zeros(ext_numFold, num_ext_metric);

            %let's start the outer cross validation!

            for i = 1:ext_numFold

                %selecting test and training set for the outer cross validation
                ext_teIndices = ext_indices == i;
                ext_trIndices = ~ext_teIndices;
                ext_trData = data(ext_trIndices,:); %#ok<COLND>
                ext_teData = data(ext_teIndices,:);
                ext_trTime = time(ext_trIndices);
                ext_teTime = time(ext_teIndices);
                ext_trCensored = censored(ext_trIndices);
                ext_teCensored = censored(ext_teIndices);

                %select the indices for this cross validation
                int_indices_i = int_indices{i,1}; %#ok<USENS>

                %let's cycling over the internal fold!
                for j = 1:int_numFold

                    %split the current internal fold
                    int_teIndices = int_indices_i == j;
                    int_trIndices = ~int_teIndices;
                    int_trData = ext_trData(int_trIndices,:); %#ok<NASGU>
                    int_teData = ext_trData(int_teIndices,:);
                    int_trTime = ext_trTime(int_trIndices); %#ok<NASGU>
                    int_teTime = ext_trTime(int_teIndices);
                    int_trCensored = ext_trCensored(int_trIndices); %#ok<NASGU>
                    int_teCensored = ext_trCensored(int_teIndices);

                    %run several parameters configurations
                    for k =1:num_FS_parameters

                        for m = 1:num_RE_parameters

                            %retrieving all the information adn calculating the
                            %internal evaluations
                            vars = int_vars{i,j,k}; %#ok<USENS>
                            int_evaluations(i,j,k,m) = feval(int_metric, int_models{i,j,k,m}, int_predictions{i,j,k,m}, int_teData(:,vars), int_teTime, int_teCensored); %#ok<USENS>

                        end

                    end

                    %calculate the mean int evaluation for each parameter
                    %configuration
                    mean_int_evaluation(i,:,:) = mean(int_evaluations(i,:,:,:),2);
                    if maximize == 1
                        absoluteMax = max(max(mean_int_evaluation(i,:,:)));
                        linearIndex = find(mean_int_evaluation(i,:,:) == absoluteMax);
                        [dummy best_FS_parameter(i) best_RE_parameter(i)] = ind2sub(size(mean_int_evaluation(i,:,:)),linearIndex(1));
                    else
                        absoluteMin = min(min(mean_int_evaluation(i,:,:)));
                        linearIndex = find(mean_int_evaluation(i,:,:) == absoluteMin);            
                        [dummy best_FS_parameter(i) best_RE_parameter(i)] = ind2sub(size(mean_int_evaluation(i,:,:)),linearIndex(1));
                    end

                end

                %calculate the evaluatins for each external fold and for each external
                %metric
                for k =1:num_ext_metric

                        vars = ext_vars{i,best_FS_parameter(i)}; %#ok<USENS>
                        model = ext_models{i,best_FS_parameter(i), best_RE_parameter(i)}; %#ok<USENS>
                        ext_evaluations(i,k) = feval(ext_metric{k}, model, ext_predictions{i, best_FS_parameter(i), best_RE_parameter(i)},...
                                ext_teData(:,vars), ext_teTime, ext_teCensored); %#ok<USENS>

                end

                %save once for each external fold    
                save(outputFile, 'int_evaluations', 'mean_int_evaluation', 'best_FS_parameter', 'best_RE_parameter', 'ext_evaluations');

            end
        end
    end
end
