function featureSelectionNestedCV(datasets, FSs)

%Description:
% This function applyes feature selection algorithms on the specified
% datasets. A nested cross valiadtion is used, i.e. the dataset is splitted
% among a set of external splits and each external split is splitted in a
% number of internal splits. The feature selection algorithm is applyed on
% each split, both external and internal. The results are then saved in a
% specific folder.

% datasets: the names of the datasets
% FS: the names of the feature selection algorithms

%setting the required directories
if isempty(findstr('FeatureSelection/', path))
    path(path, 'FeatureSelection/');
end

%let's loop over the datasets!
num_datasets = length(datasets);
for d = 1:num_datasets
    
    %choose the dataset...
    dataset = datasets{d};
    
    %let's choose the FSs...
    num_FSs = length(FSs);   
    for f = 1:num_FSs
        
        FS = FSs{f};
        disp(['Dataset: ' dataset '; Feature Selection: ' FS]);
        
        % dataset: the file must contain the variables: data, time, censored,
        % ext_indices and int_indices
        datasetfold = 'dataset/';
        datasetFile = [datasetfold dataset];
        load(datasetFile);
        int_numFold = max(int_indices{1}); %#ok<USENS>
        ext_numFold = max(ext_indices);

        %FS parameters
        %MMPC
        if strcmp(FS,'SMMPC')
            clear FS_options
            FS_options(1).threshold = 0.05;
            FS_options(1).max_k = 2;
            FS_options(2).threshold = 0.05;
            FS_options(2).max_k = 3;            
            FS_options(3).threshold = 0.1;
            FS_options(3).max_k = 2;
            FS_options(4).threshold = 0.1;
            FS_options(4).max_k = 3;
            FS_options(5).threshold = 0.15;
            FS_options(5).max_k = 2;
            FS_options(6).threshold = 0.15;
            FS_options(6).max_k = 3;
        end
        %NoSelection
        if strcmp(FS, 'noSelection')
            clear FS_options
            FS_options = 0;
        end
        %Forward Selection
        if strcmp(FS, 'forwardSelection')
            clear FS_options
            FS_options(1).ratio= 0.01;            
            FS_options(2).ratio = 0.05;
            FS_options(3).ratio = 0.1;
        end
        %Univariate Selection
        if strcmp(FS, 'univariateSelection')
            clear FS_options
            FS_options(1).threshold = 0.05;            
            FS_options(2).threshold = 0.1;
            FS_options(3).threshold = 0.15;
        end
         %MCMC Selection
         if strcmp(FS, 'MCMCSelection')
             clear FS_options
             FS_options(1).initial = 10;
             FS_options(2).initial = 20;
         end
        %Bayes score Selection
        if strcmp(FS, 'bayesScoreSelection')
            clear FS_options
            FS_options(1).sigma = 0.1;
            FS_options(2).sigma = 0.5;
            FS_options(3).sigma = 1;
        end
        %lasso Selection
        if strcmp(FS, 'lassoSelection')
            clear FS_options
            FS_options(1).bound = 0.1;
            FS_options(2).bound = 1;
            FS_options(3).bound = 10;
        end                
        num_FS_parameters = length(FS_options);

        %creation of variables to be stored
        int_vars = cell(ext_numFold,int_numFold,num_FS_parameters);
        int_statistics = cell(ext_numFold,int_numFold,num_FS_parameters);
        ext_vars = cell(ext_numFold,num_FS_parameters);
        ext_statistics = cell(ext_numFold,num_FS_parameters);
        int_CPUtimes = zeros(ext_numFold,int_numFold);
        ext_CPUtimes = zeros(ext_numFold,1);

        %output file
        outputFile = ['reducedDataset/' dataset '_' FS '.mat'];

        %let's start the outer cross validation!
        for i = 1:ext_numFold

            %selecting test and training set for the outer cross validation
            ext_teIndices = ext_indices == i;
            ext_trIndices = ~ext_teIndices;
            ext_trData = data(ext_trIndices,:); %#ok<COLND>
            ext_trTime = time(ext_trIndices);
            ext_trCensored = censored(ext_trIndices);

            %select the indices for this cross validation
            int_indices_i = int_indices{i,1}; %#ok<USENS>

            %let's cycling over the internal fold!
            for j = 1:int_numFold
                tic;
                %split the current internal fold
                int_teIndices = int_indices_i == j;
                int_trIndices = ~int_teIndices;
                int_trData = ext_trData(int_trIndices,:); %#ok<COLND>
                int_trTime = ext_trTime(int_trIndices);
                int_trCensored = ext_trCensored(int_trIndices);

                %run several parameters configurations
                for k =1:num_FS_parameters

                    disp(['Feature selection on the ' num2str(j) ' internal fold of the ' num2str(i) ' external fold']);
                    disp(['FS parameters set ' num2str(k) ' of ' num2str(num_FS_parameters) ' parameters configurations']);
                    [int_vars{i,j,k} int_statistics{i,j,k}]= feval(FS, int_trData, int_trTime, int_trCensored, FS_options(k));

                end
                int_CPUtimes(i,j) = toc;
                %save once for internal fold
                save('-v6', outputFile, 'ext_vars', 'int_vars', 'ext_statistics', 'int_statistics', 'ext_indices', 'int_indices', 'FS_options', 'ext_CPUtimes', 'int_CPUtimes');

            end

            tic;
            %run the FS on the external folds trying all the configuration
            for k =1:num_FS_parameters

                disp(['Feature selection on the ' num2str(i) ' external fold']);
                disp(['FS parameters set ' num2str(k) ' of ' num2str(num_FS_parameters) ' parameters configurations']);
                [ext_vars{i,k} ext_statistics{i,k}] = feval(FS, ext_trData, ext_trTime, ext_trCensored, FS_options(k));

            end
            ext_CPUtimes(i,1) = toc;
            %save again for safety
            save('-v6',outputFile, 'ext_vars', 'int_vars', 'ext_statistics', 'int_statistics', 'ext_indices', 'int_indices', 'FS_options', 'ext_CPUtimes', 'int_CPUtimes');

        end
        
    end

end