%script for performing nested cross validated experiments

%silent warning
warning off MATLAB:dispatcher:pathWarning

%updating path
path(path, 'FeatureSelection');
path(path, 'Regression');

%which dataset will we use?
%datasets={'1_vanVijver', '2_vanVeer', '3_Rosenwald-2002', '4_Rosenwald-2003', '5_Bullinger', '6_Beer'};
datasets={'1_vanVijver'};

%Feature selection methods
%FSs = {'noSelection', 'univariateSelection', 'forwardSelection', 'MCMCSelection', 'bayesScoreSelection', 'lassoSelection', 'SMMPC'};
FSs = {'lassoSelection'};


%Regression method
%REs = {'coxRegression', 'AFT', 'ridgeRegression', 'RSF', 'SVCR'};
REs = {'ridgeRegression'};

%Let's create the parameters for the regressor
REs_parameters = createRegressionParameters(REs);

%which metric will we apply on the outer loop of nested cross validation?
ext_metric = {'CI', 'IBS', 'nVars'};

%metric to optimize on the inner loop (only one metric allowed). 
%Note: IBS must be minimized (maximize = -1);
int_metric = 'CI';
maximize = 1;

%baseline methods for the permutation test and permutation test direction; 
%With this settings, we will test if SMMPC coupled with ridge regression
%produces larger performances than the other methods (note that if the
%performance of SMMPC is larger than the performance of an other method in
%terms of CI, than SMMPC is better than the other method; conversely for
%the IBS.
FS_base = 'SMMPC';
RE_base = 'ridgeRegression';
test_direction = 'G';
numPermutations = 1000;

%Let's select the variables! If you use the MCMCSelection, it will take a 
%lot (i.e. months). The resulting dataset will be saved in the 
%"reducedDataset" folder.
featureSelectionNestedCV(datasets, FSs);

%%Let's perform the regression! Results will be stored in the
%%"regressionResults' folder. Please note that the combination of
%%noSelection and SVCR is tremendously slow.
regressionNestedCV(datasets, FSs, REs, REs_parameters)

%Let's select the best parameters setting on each internal fold and let's
%apply all metrics to the external folds.
evaluationNestedCV(datasets, FSs, REs, ext_metric, int_metric, maximize)

%Let's synthesize the results! Two matrix will be saved in the
%ResultsSynthesis.mat file:
%    ext_metric_means: this matrix contains the performance overaged over
%    the external folds for each combination of variable selection method,
%    dataset, regressor and metric. For example, ext_metric_means(1,2,3,4)
%    contains the performance of the first variable selection method, on
%    the second dataset, with the third regressor and the fourth metric
%    perm_test_comparisons = pvalues from the permutation test. For
%    example, if perm_test_comparisons(1,2,3,4) = 0.02, we can say that
%    SMMPC coupled with ridge regression gives higher results (as measured
%    with the fourth metric) on the second dataset than the first variable
%    selection algorithm coupled with the third regressor.
resultsSynthesis(datasets, FSs, REs, ext_metric, FS_base, RE_base, test_direction, numPermutations)


