function [CIA CIB] = CIpermutation(modelA, predsA, modelB, predsB, time, censored)

%this function compute a permuted c - index for two different set of
%predictions

%let's find the type of the model
direct = {'SVCR', 'RSF', 'AFT'};
modelAType = modelA.type;
modelBType = modelB.type;

%adjusting for model type
if sum(strcmp(modelAType, direct)) == 1
	predsA = -predsA;
end
if sum(strcmp(modelBType, direct)) == 1
	predsB = -predsB;
end

%relative risks
pairsA = nchoosek(predsA,2);
RRA = pairsA(:,1) > pairsA(:,2);
ERA = pairsA(:,1) == pairsA(:,2);
pairsB = nchoosek(predsB,2);
RRB = pairsB(:,1) > pairsB(:,2);
ERB = pairsB(:,1) == pairsB(:,2);

%let's swap the pairs!
npairs = size(pairsA,1);
perm = rand(npairs,1);
perm = perm > 0.5;
tempRR = RRA;
RRA(perm) = RRB(perm);
RRB(perm) = tempRR(perm);

%time and censored pairs
timePairs = nchoosek(time, 2);
censoredPairs = nchoosek(censored, 2);

%let's compute the CIs!
comparable = ~(((timePairs(:,1) <= timePairs(:,2)) & censoredPairs(:,1) == 1) |...
                ((timePairs(:,2) <= timePairs(:,1)) & censoredPairs(:,2) == 1));  %#ok<AND2>
            
swappedA = comparable & ((timePairs(:,1) < timePairs(:,2) & (~RRA | ERA)) |...
                         (timePairs(:,2) < timePairs(:,1) & (RRA | ERA)) |... 
                         (timePairs(:,1) == timePairs(:,2) & ~ERA));

swappedB = comparable & ((timePairs(:,1) < timePairs(:,2) & (~RRB | ERB)) |... 
                         (timePairs(:,2) < timePairs(:,1) & (RRB | ERB)) |... 
                         (timePairs(:,1) == timePairs(:,2) & ~ERB));

CIA = (sum(comparable) - sum(swappedA))/sum(comparable);
CIB = (sum(comparable) - sum(swappedB))/sum(comparable);
