function [IBSA IBSB] = IBSpermutation(modelA, predsA, modelB, predsB, time, censored)

    %let's chech if both models have the same timeOfInterest
    if length(modelA.timeOfInterest) ~= length(modelB.timeOfInterest)

        %the only possible reason is that one of the two models has some
        %duplicate in its timeOfInterest. Thus, let's make them the same!
        if length(modelA.timeOfInterest) > length(modelB.timeOfInterest)
            modelA = fixModel(modelA);
        else
            modelB = fixModel(modelB);
        end

    end

    %let's swap the Survival functions!
    numSamples = size(modelA.S,1);
    perm = rand(numSamples,1);
    perm = perm > 0.5;
    tempS = modelA.S;

    modelA.S(perm,:) = modelB.S(perm,:);
    modelB.S(perm,:) = tempS(perm,:);

    IBSA = IBS(modelA, predsA, [], time, censored);
    IBSB = IBS(modelB, predsB, [], time, censored);

end

function model = fixModel(model)

    %looking for duplicates
    idx = find((model.timeOfInterest - [model.timeOfInterest(2:end); 0]) == 0) + 1;
    
    model.timeOfInterest(idx) = [];
    model.S(:,idx) = [];
    
end