function [pvalue valueA valueB permValuesA permValuesB] = permutationTest(metric, direction, num_perms, predsA, modelA, predsB, modelB, time, censored)

%This function performs a permutation test in order to assess whether two
%performances, i.e. metric(A) and metric(b), are different.
%Metric is the used metric;
%direction: 
%   G: the null hypothesis metric(A) = metric(B) is tested
%   against metric(A) > metric(B) 
%   L: the null hypothesis metric(A) = metric(B) is tested
%   against metric(A) < metric(B)
%   D: the null hypothesis metric(A) = metric(B) is tested
%   against metric(A) != metric(B)

%real values
valueA = feval(metric, modelA, predsA, [], time, censored);
valueB = feval(metric, modelB, predsB, [], time, censored);

%vars to be saved
permValuesA = nan(num_perms, 1);
permValuesB = nan(num_perms, 1);

%nVars metric
if strcmp(metric, 'nVars')
    pvalue = 1;
    valueA = 0;
    valueB = 0;
    permValuesA = zeros(num_perms, 1);
    permValuesB = zeros(num_perms, 1);
    return;
end

%CI metric
if strcmp(metric, 'CI')
    metric = 'CIpermutation';
end
%IBS metric
if strcmp(metric, 'IBS')
    metric = 'IBSpermutation';
end

%for each permutation
for p = 1:num_perms
    
    [permValuesA(p,1) permValuesB(p,1)] = feval(metric, modelA, predsA, modelB, predsB, time, censored);
      
end


%let's calculate the p value
if strcmp(direction, 'G')
    stat = valueA - valueB;
    distr = permValuesA - permValuesB;
    pvalue = sum(distr >= stat)/num_perms;
end

if strcmp(direction, 'L')
    stat = valueA - valueB;
    distr = permValuesA - permValuesB;
    pvalue = sum(distr <= stat)/num_perms;
end

if strcmp(direction, 'D')
    stat = valueA - valueB;
    distr = permValuesA - permValuesB;
    pvalue = sum(abs(distr) <= abs(stat))/num_perms;
end