function [] = regressionNestedCV(datasets, FSs, REs, REs_parameters)

% Description:
% This function executes the regression algorithms on the reduced datasets
% provided by the features selection algorithms. Both models and test set
% predictions are stored.
%
% datasets: datasets to work on
% FSs: features selection algorithms
% REs: regression algorithms
% REs_parameters: the parameters for the regression algorithm


%uploading the path
if isempty(findstr('Regression/', path))
    path(path, 'Regression/');
end

%hard coded parameters
datasetfold = 'dataset/';
reducedDatasetFold = 'reducedDataset/';
resultsFold = 'regressionResults/';

%let's loop on the datasets set
for d = 1:length(datasets)

    dataset = datasets{d};
    datasetFile = [datasetfold dataset];
    load(datasetFile);

    %finding the number of external and internal CV
    ext_numFold = max(ext_indices);
    int_numFold = max(int_indices{1,1}); %#ok<USENS>
    
    %loop over the FS
    for f = 1:length(FSs)

        FS = FSs{f};

        disp(['Dataset: ' dataset ' method: ' FS]);

        %loading pre computed variables sets.
        load([reducedDatasetFold dataset '_' FS]);
        num_FS_parameters = length(FS_options);

		%loop over the REs
		for r = 1:length(REs)
			
			%selecting the current regressor
			RE = REs{r};
			RE_options = REs_parameters{r};
			
		    %num Regression algorithm parameters
		    num_RE_parameters = length(RE_options);

		    %creation of variables to be stored
		    int_predictions = cell(ext_numFold, int_numFold, num_FS_parameters, num_RE_parameters);
		    int_models = cell(ext_numFold, int_numFold, num_FS_parameters, num_RE_parameters);
		    ext_predictions = cell(ext_numFold, num_FS_parameters, num_RE_parameters);
		    ext_models = cell(ext_numFold, num_FS_parameters, num_RE_parameters);

		    %output file
		    outputFile = [resultsFold dataset '_' FS '_' RE];

		    %let's start the outer cross validation!
		    for i = 1:ext_numFold

		        %selecting test and training set for the outer cross validation
		        ext_teIndices = ext_indices == i;
		        ext_trIndices = ~ext_teIndices;
		        ext_trData = data(ext_trIndices,:); %#ok<COLND>
		        ext_teData = data(ext_teIndices,:); %#ok<COLND>
		        ext_trTime = time(ext_trIndices);
		        ext_teTime = time(ext_teIndices);
		        ext_trCensored = censored(ext_trIndices);
		        ext_teCensored = censored(ext_teIndices);

		        %select the indices for this cross validation
		        int_indices_i = int_indices{i}; %#ok<USENS>

		        %let's cycling over the internal fold!
		        for j = 1:int_numFold

		            %split the current internal fold
		            int_teIndices = int_indices_i == j;
		            int_trIndices = ~int_teIndices;
		            int_trData = ext_trData(int_trIndices,:); %#ok<COLND>
		            int_teData = ext_trData(int_teIndices,:); %#ok<COLND>
		            int_trTime = ext_trTime(int_trIndices);
		            int_teTime = ext_trTime(int_teIndices);
		            int_trCensored = ext_trCensored(int_trIndices);
		            int_teCensored = ext_trCensored(int_teIndices);

		            %run several parameters configurations
		            for k =1:num_FS_parameters
		                
		                for m = 1:num_RE_parameters
		                    disp(['Ext fold: ' num2str(i) ' ' 'Int fold: ' num2str(j) ' FS: ' FS ' FS par: ' num2str(k) ' RE: ' RE ' RE par: ' num2str(m)]);
		                    vars = int_vars{i,j,k}; %#ok<USENS>
		                    [int_models{i,j,k,m} int_predictions{i,j,k,m}] = feval(RE, int_trData(:,vars), int_trTime, int_trCensored, int_teData(:,vars), int_teTime, int_teCensored, RE_options(m));

		                end

		            end

		            %save once for internal fold
		            save(outputFile, 'ext_predictions', 'int_predictions', 'ext_models', 'int_models', 'FS_options', 'RE_options', 'ext_vars', 'int_vars');

		        end

		        %run the FS on the external folds trying all the configuration
		        for k =1:num_FS_parameters

		            for m = 1:num_RE_parameters
		                vars = ext_vars{i,k}; %#ok<USENS>
		                [ext_models{i,k,m} ext_predictions{i,k,m}] = feval(RE, ext_trData(:,vars), ext_trTime, ext_trCensored, ext_teData(:,vars), ext_teTime, ext_teCensored, RE_options(m));
		            end

		        end

		        %save again for safety
		        save(outputFile, 'ext_predictions', 'int_predictions', 'ext_models', 'int_models', 'FS_options', 'RE_options', 'ext_vars', 'int_vars');

		    end
		    
		end
		
    end
    
end
